@@ -1,4 +1,5 @@
 from classytags.core import Tag
+from classytags.utils import flatten_context
 from django.core.exceptions import ImproperlyConfigured
 from django.template.loader import render_to_string
 
@@ -67,6 +68,7 @@ class InclusionTag(Tag):
     Optionally override get_template in your subclasses.
     """
     template = None
+    push_context = False
 
     def render_tag(self, context, **kwargs):
         """
@@ -75,8 +77,14 @@ class InclusionTag(Tag):
         Gets the context and data to render.
         """
         template = self.get_template(context, **kwargs)
-        data = self.get_context(context, **kwargs)
-        output = render_to_string(template, data)
+        if self.push_context:
+            safe_context = flatten_context(context)
+            data = self.get_context(safe_context, **kwargs)
+            safe_context.update(**data)
+            output = render_to_string(template, safe_context)
+        else:
+            data = self.get_context(context, **kwargs)
+            output = render_to_string(template, data)
         return output
 
     def get_template(self, context, **kwargs):
